@@ -4,7 +4,7 @@ import numpy as np
 import pytest
 
 
-class TestRegularizationConstantMatrix:
+class TestRegularizationinstanceMatrix:
     def test__1_b_matrix_size_3x3__weights_all_1s__makes_correct_regularization_matrix(
         self
     ):
@@ -156,7 +156,7 @@ class TestRegularizationConstantMatrix:
         assert abs(np.linalg.det(regularization_matrix)) > 1e-8
 
 
-class TestRegularizationWeightedRegularizationWeights(object):
+class TestRegularizationWeightedRegularizationWeights:
     def test__pixel_signals_all_1s__coefficients_all_1s__weights_all_1s(self):
 
         pixel_signals = np.array([1.0, 1.0, 1.0])
@@ -394,7 +394,7 @@ class TestRegularizationWeightedMatrix:
             test_regularization_matrix, 1.0e-4
         )
 
-    def test__2_b_matrices_size_4x4_variables_regularization_weights__makes_correct_regularization_matrix(
+    def test__2_b_matrices_size_4x4_models_regularization_weights__makes_correct_regularization_matrix(
         self
     ):
         # Simple case, where we have just one regularization direction, regularizing pixel 0 -> 1 and 1 -> 2.
